@@ -116,6 +116,15 @@ EOJS
                                            );
     }
     
+    # -------------------------
+    elsif ( $mode eq 'editrelated' )
+    {
+        $args->{action} = $r->make_path( table      => $proto->table,
+                                         action     => 'do_editrelated',
+                                         %additional, 
+                                         );
+    }
+    
     # -------------------------
     else
     {
